@@ -7,7 +7,7 @@ use Catalyst::Log;
 
 __PACKAGE__->mk_classdata($_) for qw/_config log/;
 
-our $VERSION = '4.12';
+our $VERSION = '4.13';
 our @ISA;
 
 =head1 NAME
@@ -17,7 +17,7 @@ Catalyst - The Elegant MVC Web Application Framework
 =head1 SYNOPSIS
 
     # use the helper to start a new application
-    perl /path/to/catalyst MyApp
+    catalyst MyApp
     cd MyApp
 
     # add models, views, controllers
